Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/intern
diff options
context:
space:
mode:
Diffstat (limited to 'intern')
-rw-r--r--intern/ghost/intern/GHOST_SystemCarbon.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/intern/ghost/intern/GHOST_SystemCarbon.h b/intern/ghost/intern/GHOST_SystemCarbon.h
index 51c2a4f0a7a..62d45ee769d 100644
--- a/intern/ghost/intern/GHOST_SystemCarbon.h
+++ b/intern/ghost/intern/GHOST_SystemCarbon.h
@@ -177,9 +177,9 @@ public:
/**
* Puts buffer to system clipboard
* @param buffer The buffer to be copied
* @param flag Indicates which buffer to copy too Only used on X11
*/
- virtual void putClipboard(GHOST_TInt8 *buffer, int flag) const;
+ virtual void putClipboard(GHOST_TInt8 *buffer, bool selection) const;
protected:
/**
@@ -177,9 +177,9 @@ public:
* Puts buffer to system clipboard
* @param buffer The buffer to be copied
- * @param flag Indicates which buffer to copy too Only used on X11
+ * @param selection Indicates which buffer to copy too, only used on X11
*/